<?php

/**
 * Jelentkezési lap fő függvénye
 * @param array() $form - Az űrlap adatai
 * @parama array() $form_state - jelentkezés állapota
 */

function fz_form_jel($form, &$form_state){
  $path = drupal_get_path("module", "fz_form");
  drupal_add_css($path. "/css/jel.css","file");
  drupal_add_js($path . '/js/jel.js');
  $test = variable_get("fz_form_test", False);

  if(!isset($form)){
    $form = array();
  }
  //Melyik oldalon vagyunk
  if(!isset($form_state['step'])){
    $form_state['step']=1;
  }
  
  if(!isset(  $form_state["values"]['ido'])){
    $form_state["values"]['ido'] = date("Y.m.d H:m:s");
  }
  
  switch ($form_state['step']){
    case 1:
      $form = fz_form_intro($form_state);
      break;
    case 2:
      $form = fz_form_szakma($form_state);
      break;
    case 3:
      $form = fz_form_szemelyes($form_state);
      break;
    case 4:
      $form = fz_form_korabbi($form_state);
      break;
    case 5:
      $form = fz_form_utolso($form_state);
      break;
  }
  return $form;
}

/**
 * Elküldés gombokat ad az űrlap aljához
 * @param unknown $form
 * @param unknown $form_state
 */
function fz_form_add_submit_buttons(&$form, &$form_state){
  if($form_state['step'] > 1){
    $form['prev'] = array(
        '#type'  => "submit",
        '#value' => "Előző oldal"
    );
  }
  
  if($form_state['step'] < 5){
    $form['next'] = array(
        '#type'  => "submit",
        '#value' => "Következő oldal"
    );
    
  }
  
  if($form_state['step'] == 5){
    $form['finish'] = array(
        '#type'  => "submit",
        '#value' => "Jelentkezés elküldése"
    );
  }
}

/**
 * * A több oldalas űrlap továbbléptetése
 * @param array $form
 * @param array $form_state
 */
function fz_form_jel_submit($form, &$form_state){
  
  $form_state['storedvalues'][$form_state['step']] = $form_state['values'];

  
  switch($form_state['clicked_button']["#id"] ){
    case 'edit-submit':
    case 'edit-next':
      $form_state['rebuild'] = TRUE;
      $form_state['step']++;
      break;

    case 'edit-prev':
      $form_state['rebuild'] = TRUE;
      $form_state['step']--;
      break;
    case 'edit-finish':
      $time = date('Y.m.d H:i:s');
      $v    = fz_form_stored_values($form_state,$time);
      //Test purposes
      $mailmsg = array('msg'=> "Egy levelet küldtünk Önnek, amiben .....", 'mode'=>'warning');
      $ok      = fz_form_move_files($v);
      $id      = fz_form_save($v);
      $mailmsg = fz_form_send_mail($v, $time, $id);
      if(variable_get("fz_form_mail_to_school")){
        $mailmsg = fz_form_send_mail($v, $time, $id, variable_get("fz_form_mail_to_school_from"), FZ_FORM_DEFAULT_SENDER_MAIL);
      }
      $link    = fz_form_pdf($v, $time, $id);
      
      //Adatok átadása a befejező oldalnak
      $_SESSION['fz_form']['id']      = $id;
      $_SESSION['fz_form']['link']    = $link;
      $_SESSION['fz_form']['mailmsg'] = $mailmsg;
      $_SESSION['fz_form']['confirm'] = $v['confirm'];
      $_SESSION['fz_form']['ido']     = $v['ido'];
      $_SESSION['fz_form']['nev']     = $v['nev'];

      $form_state['redirect']         ="fz_form/elkuldve";
      $form_state['rebuild']          = FALSE;
      break;
  }
}

/**
 * A letárolt adatok átrakása és kinyerése
 * @param unknown $form_state
 * @param unknown $time
 * @return string[]|unknown[]
 */
function fz_form_stored_values(&$form_state,$time){
  $v=array();
  
  foreach($form_state['storedvalues'] As $j => $page){
    foreach($page AS $i => $e){
      $v[$i] =$e;
    }
  }
  $v['status'] = '---';
  unset($v['form_build_id']);
  unset($v['form_token']);
  unset($v['form_build_id']);
  unset($v['form_id']);
  unset($v['op']);
  unset($v['submit']);
  unset($v['next']);
  unset($v['prev']);
  unset($v['valodi']);
  unset($v['finish']);
  $v['confirm'] = fz_form_md5($v,$time);
  $form_state['fz_form']['confirm'] = $v['confirm'];
  return $v;
}

/**
 * Make md5 from array
 * @param array $v
 * @return string
 */

function fz_form_md5($v=array(),$time){
  $s = md5($time.$v['ido'].$v['okj'].$v['kezdes'].$v['iskola'].$v['nev'].$v['anyjaneve'].$v['szulhely'].$v['szulido'] );
  return $s;
}

/**
 * A jelentkezési lap mentése
 * @param unknown $form
 * @param unknown $form_state
 */
function fz_form_save(&$v){
  unset($v['letszam']);
  unset($v['maxletszam']);
  unset($v['szabad']);
  $id = db_insert('fz_form_app')
            ->fields($v)
            ->execute();
  return $id;
}

/**
 * Az fz_form_jel validálása
 * @param unknown $form
 * @param unknown $form_state
 */
function fz_form_jel_validate(&$form, &$form_state) {
  // oktatási azonosító ellenőrzése
  if( isset( $form_state["values"]["oktazon"] ) &&
      (
        strlen(str_replace(' ','',$form_state["values"]["oktazon"])) != 11 ||
        substr($form_state["values"]["oktazon"],0,1) !="7"
      )
  ){
     form_set_error("oktazon","Az oktatási azonosító 7-essel kezdődik és 11 jegyű!<br/> Ha nincsen oktatási azonosítója, akkor írjon ide 11 db 7-est!");
  }

  //Telefonszám formátumának ellenőrzése
  if(isset($form_state["values"]["tel"]) ){
    $tel = preg_replace("/[^0-9|\+]/","", $form_state["values"]["tel"]);
    if(strlen($tel) < 6 ){
      form_set_error("tel","A telefonszám 6 db számnál nem lehet rövidebb<br/>Az elején lehet: '+', tartalmazhat számokat, szóközt, zárójeleket!");
    }
  }
  
  //Email cím ellenőrzése
  if(isset($form_state["values"]["email"]) && ! valid_email_address($form_state["values"]["email"])){
    form_set_error("email","Az érvényes email címben lennie kell egy @ jelnek is!");
  }
  
  //TAJ szám ellenőrzése
  if( isset($form_state["values"]["taj"]) &&
      strlen(str_replace(' ','', $form_state["values"]["taj"])) != 9
  ){
    form_set_error("taj","A TAJ azonosító 9 számjegyből áll!");
  }
  
  //A fenti adatok a valóságnak megfelelnek
  if($form_state['clicked_button']["#id"] == "edit-next" &&
      $form_state["step"]== 3 &&
      isset( $form_state["values"]["valodi"] ) &&
      $form_state["values"]["valodi"] == 0
  ){
    form_set_error("valodi","<b>A fenti adatok a valóságnak megfelelnek</b> állítást kötelező elfogadni!");
  }
}
